@@ -33,9 +33,10 @@
 #  define CMARK_DEPRECATED_NO_EXPORT CMARK_NO_EXPORT CMARK_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define CMARK_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef CMARK_NO_DEPRECATED
+#    define CMARK_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
